import argparse

from .. import __version__
from .predict import PredictAutoXGBCommand
from .serve import ServeAutoXGBCommand
from .train import TrainAutoXGBCommand


def main():
    parser = argparse.ArgumentParser(
        "AutoXGB CLI",
        usage="xgbauto <command> [<args>]",
        epilog="For more information about a command, run: `autoxgb <command> --help`",
    )
    parser.add_argument("--version", "-v", help="Display AutoXGB version", action="store_true")

    commands_parser = parser.add_subparsers(help="commands")
    TrainAutoXGBCommand.register_subcommand(commands_parser)
    PredictAutoXGBCommand.register_subcommand(commands_parser)
    ServeAutoXGBCommand.register_subcommand(commands_parser)

    args = parser.parse_args()

    if args.version:
        print(__version__)
        exit(0)

    if not hasattr(args, "func"):
        parser.print_help()
        exit(1)

    command = args.func(args)
    command.execute()


if __name__ == "__main__":
    main()



from argparse import ArgumentParser

from ..predict import AutoXGBPredict
from . import BaseCommand


def predict_autoxgb_command_factory(args):
    return PredictAutoXGBCommand(args.model_path, args.test_filename, args.out_filename)


class PredictAutoXGBCommand(BaseCommand):
    @staticmethod
    def register_subcommand(parser: ArgumentParser):
        _parser = parser.add_parser("predict", help="Make predictions on any CSV file")
        _parser.add_argument("--model_path", help="Path to model", required=True, type=str)
        _parser.add_argument("--test_filename", help="Path to test file", required=False, type=str, default=None)
        _parser.add_argument("--out_filename", help="Path to output file", required=True, type=str)
        _parser.set_defaults(func=predict_autoxgb_command_factory)

    def __init__(self, model_path, test_filename, out_filename):
        self.model_path = model_path
        self.test_filename = test_filename
        self.out_filename = out_filename

    def execute(self):
        axgb = AutoXGBPredict(model_path=self.model_path)
        axgb.predict_file(test_filename=self.test_filename, out_filename=self.out_filename)
